Examples based on real world datasets — Version 0.11.0.dev0

# Examples based on real world datasets

Examples which use real-word dataset.

Multiclass classification with under-sampling

Multiclass classification with under-sampling

Example of topic classification in text documents

Example of topic classification in text documents

Customized sampler to implement an outlier rejections estimator

Customized sampler to implement an outlier rejections estimator

Benchmark over-sampling methods in a face recognition task

Benchmark over-sampling methods in a face recognition task

Porto Seguro: balancing samples in mini-batches with Keras

Porto Seguro: balancing samples in mini-batches with Keras

Fitting model on imbalanced datasets and how to fight bias

Fitting model on imbalanced datasets and how to fight bias

previous

How to use `sampling_strategy` in imbalanced-learn

next

Multiclass classification with under-sampling